"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceColorsFromImage = exports.applyFilters = exports.convertImageToBase64 = exports.getImageBuffer = exports.clearImage = void 0;
const gm_1 = __importDefault(require("gm"));
const jimp_1 = __importDefault(require("jimp"));
const replace_color_1 = __importDefault(require("replace-color"));
async function clearImage(imgPath) {
    const jimp = await jimp_1.default.read(imgPath);
    return jimp
        .resize(400, jimp_1.default.AUTO)
        .color([{ apply: "desaturate", params: [0] }])
        .contrast(1)
        .normalize();
}
exports.clearImage = clearImage;
async function getImageBuffer(imgJimp) {
    return await imgJimp.getBufferAsync(jimp_1.default.MIME_PNG);
}
exports.getImageBuffer = getImageBuffer;
function convertImageToBase64(image) {
    return Buffer.from(image).toString("base64");
}
exports.convertImageToBase64 = convertImageToBase64;
function applyFilters(img) {
    return new Promise((resolve, reject) => {
        gm_1.default(img)
            .median(3)
            .enhance()
            .toBuffer("PNG", function (err, buffer) {
            if (err) {
                reject(err);
            }
            resolve(buffer);
        });
    });
}
exports.applyFilters = applyFilters;
async function replaceColorsFromImage(img, colorsToReplace = []) {
    if (colorsToReplace.length > 0) {
        return colorsToReplace.reduce(async (acc, curr, index) => {
            try {
                if (index === 0) {
                    acc = await replace_color_1.default({
                        image: img,
                        colors: {
                            type: "hex",
                            targetColor: curr.targetColor,
                            replaceColor: curr.newColor,
                        },
                        deltaE: 0,
                    });
                }
                else {
                    const accJimp = await acc;
                    acc = await replace_color_1.default({
                        image: await getImageBuffer(accJimp),
                        colors: {
                            type: "hex",
                            targetColor: curr.targetColor,
                            replaceColor: curr.newColor,
                        },
                        deltaE: 0,
                    });
                }
                return acc;
            }
            catch (err) {
                throw err;
            }
        }, {});
    }
    return await jimp_1.default.read(img);
}
exports.replaceColorsFromImage = replaceColorsFromImage;
//# sourceMappingURL=imageManipulation.js.map